ContractState

Struct ContractState 

pub struct ContractState {
Show 15 fields pub assets: Box<Assets>, pub block: Option<Box<BlockHeader>>, pub continuations: Option<String>, pub contract_id: String, pub current_contract: Option<Box<Contract>>, pub initial_contract: Box<Contract>, pub metadata: HashMap<String, Metadata>, pub role_token_minting_policy_id: String, pub state: Option<Box<MarloweState>>, pub status: TxStatus, pub tags: HashMap<String, Metadata>, pub tx_body: Option<Box<TextEnvelope>>, pub unclaimed_payouts: Vec<Payout>, pub utxo: Option<String>, pub version: MarloweVersion,
}

Fields

assets: Box<Assets>block: Option<Box<BlockHeader>>continuations: Option<String>contract_id: String

A reference to a transaction output with a transaction ID and index.

current_contract: Option<Box<Contract>>initial_contract: Box<Contract>metadata: HashMap<String, Metadata>role_token_minting_policy_id: String

The hex-encoded minting policy ID for a native Cardano token

state: Option<Box<MarloweState>>status: TxStatustags: HashMap<String, Metadata>tx_body: Option<Box<TextEnvelope>>unclaimed_payouts: Vec<Payout>utxo: Option<String>

A reference to a transaction output with a transaction ID and index.

version: MarloweVersion

Implementations

Source

impl ContractState

pub fn new( assets: Assets, contract_id: String, initial_contract: Contract, metadata: HashMap<String, Metadata>, role_token_minting_policy_id: String, status: TxStatus, tags: HashMap<String, Metadata>, unclaimed_payouts: Vec<Payout>, version: MarloweVersion, ) -> ContractState