pub struct ContractState {Show 15 fields
pub assets: Box<Assets>,
pub block: Option<Box<BlockHeader>>,
pub continuations: Option<String>,
pub contract_id: String,
pub current_contract: Option<Box<Contract>>,
pub initial_contract: Box<Contract>,
pub metadata: HashMap<String, Metadata>,
pub role_token_minting_policy_id: String,
pub state: Option<Box<MarloweState>>,
pub status: TxStatus,
pub tags: HashMap<String, Metadata>,
pub tx_body: Option<Box<TextEnvelope>>,
pub unclaimed_payouts: Vec<Payout>,
pub utxo: Option<String>,
pub version: MarloweVersion,
}Fields
assets: Box<Assets>block: Option<Box<BlockHeader>>continuations: Option<String>contract_id: StringA reference to a transaction output with a transaction ID and index.
current_contract: Option<Box<Contract>>initial_contract: Box<Contract>metadata: HashMap<String, Metadata>role_token_minting_policy_id: StringThe hex-encoded minting policy ID for a native Cardano token
state: Option<Box<MarloweState>>status: TxStatustx_body: Option<Box<TextEnvelope>>unclaimed_payouts: Vec<Payout>utxo: Option<String>A reference to a transaction output with a transaction ID and index.
version: MarloweVersionImplementations
Sourceimpl ContractState
impl ContractState